@@ -1,4 +1,5 @@
 mod macros;
+mod executer_option;
 mod sql_quote;
 mod sql_bind;
 mod curd;
@@ -7,6 +8,7 @@ pub use self::curd::*;
 pub use self::sql_quote::*;
 pub use self::sql_bind::*;
 pub use self::macros::*;
+pub use self::executer_option::*;
 pub use sqlx_model_macros::*;
 
 
